Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LoadMonaxSpec ¶
LoadMonaxSpec takes the embedded OpenAPI spec for the Monax API and loads it into a structured object using the getkin openapi3 library
Types ¶
type Describe ¶
Describe is the struct that provides the configuration object sent to the describe command
type Nax ¶
type Nax struct {
Destination string
Arguments []string
UglyPrint bool
Verbose bool
Apply *Apply
Build *Build
Describe *Describe
Get *Get
Login *Login
Run *Run
}
Nax is the primary configuration object that is leveraged by the nax runtime. It contains all of the available configuration objects.
func GetDefaultNax ¶
func GetDefaultNax() *Nax
GetDefaultNax returns a Nax config object with the default paramemters suppled. This should be called only once within the main function of the runtime and populated with flags, env vars and config files only AFTER running this function which should be thought of as the 'new' func.ß
Click to show internal directories.
Click to hide internal directories.