project

package
v0.0.35 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 23, 2019 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var History relic.ImmutableHistory = relic.NewHistory("Nax", "https://github.com/monax/nax").
	WithChangelogTemplate(template.Must(template.New("naxChangeLog").
		Parse(`# [{{ .Project }}]({{ .ProjectURL }}) Changelog{{ range .Releases }}

## [{{ .Version }}]{{ if .Version.Dated }} - {{ .Version.FormatDate }}{{ end }}

### Notes

`+NotesAndInstall()+`

### [Changes](#commits){{ end }}

## Commits
{{ range .ReleasePairs }}
* [{{ .Version }}]({{ $.URL }}/compare/{{ .Previous.Version.Ref }}...{{ .Version.Ref }})
{{- end }}
* [{{ .FirstRelease.Version }}]({{ $.URL }}/commits/{{ .FirstRelease.Version.Ref }})
`))).
	MustDeclareReleases(
		"0.0.35 - 2019-09-24", "Done...?",
		"0.0.34 - 2019-09-24", "Killing it!",
		"0.0.33 - 2019-09-24", "One more time!",
		"0.0.32 - 2019-09-24", "And.... again!",
		"0.0.31 - 2019-09-24", "Next step in testing installs",
		"0.0.30 - 2019-09-24", "Final snap hotfix?",
		"0.0.29 - 2019-09-24", "Hotfix snap plugs",
		"0.0.28 - 2019-09-24", "Hotfix bad goreleaser.",
		"0.0.27 - 2019-09-24", `We are all set now. 
		
Quite a few modifications to goreleaser. Modifications and systematization of
installation instructions. That pipeline is ready to go now. Added preliminary
tests that will use installation.`,
		"0.0.26 - 2019-09-24", "Hotfix bad release ov v0.0.25",
		"0.0.25 - 2019-09-23", `Updated changelog template to ease installation instructions.

Additionally, debian and rpm releases are now properly signed.`,
		"0.0.24", "Add usage to readme",
		"0.0.23", "Releases appear to be sorted... finally!",
		"0.0.22", "Goreleaser tweaks",
		"0.0.21", "A round and around and ar ound we go.",
		"0.0.20", "Fixes for the go.mod dirtiness",
		"0.0.19", "Final test for setup?",
		"0.0.18", "Github actions are all set up and we now have a new tool overview in cmd.",
		"0.0.17", "At some point this is gonna be settled. Adding scoop, refining snaps.",
		"0.0.16", `Houston

pronounced HOW-stun

we are good for liftoff`,
		"0.0.15", "Fixups",
		"0.0.14", `The tool has been renamed from MONAX to nax.

The license has also been changed from Parity v6.0 to Apache v2.0
this is due to the neccesity for software that is "touched" by
Parity to be made publicly available. That is a good thing which
marmots generally support, but in the case of this API wrapper
it implicates packages of contracts and templates touched
by this software and my [@compleatang] interpretation of this
is that there is an application of the license to these contracts
which would violate the intention of the tool. As such I have
chosen, for now to move to Apache v2.0.
`,
		"0.0.13", "Last go!",
		"0.0.12", "Renamed tool to just MONAX; finalized release pathways",
		"0.0.11", "Okay, I think I found the problem",
		"0.0.10", "Once more into the breach",
		"0.0.9", "Final answer?",
		"0.0.8", "More releaser tweaks",
		"0.0.7", "I think we've got it now",
		"0.0.6", "Finish up infrastructure tests -- hopefully",
		"0.0.5", "Testing release process with goreleaser",
		"0.0.4",
		`Next release of Monax Sync which has most of the target infrastructure done.

Currently we have the base infrastructure for:
- cli
- cli help text
- versioning
- notes + changelog
- logging
- basic project structure

Next steps:
- build tests based on mocks from monax-go
- build tests based on object structures extracted from monax's demo content
- make the tests go red

Targets:
1. deploy and sync archetypes
2. deploy and sync agreements (with demo content filled in)
3. manage users and organizations`,
		"0.0.3", "Even more boilerplate",
		"0.0.2", "More boilerplate",
		"0.0.1",
		`First release of Monax synx extracted from various initial projects, it can:
- Set up it's template
`)

History is the releases described by version string and changes, newest release first. The current release is taken to be the first release in the slice, and its version determines the single authoritative version for the next release.

To cut a new release add a release to the front of this slice then run the release tagging script: ./scripts/tag_release.sh

Functions

func Commit

func Commit() string

Commit returns the latest git commit

func DarwinInstall added in v0.0.25

func DarwinInstall() string

DarwinInstall provides the brew install instructions

func DebInstall added in v0.0.25

func DebInstall() string

DebInstall provides the debian install instructions

func FullVersion

func FullVersion() string

FullVersion Can be used to set the commit hash version of the binary at build time with: `go build -ldflags "-X github.com/monax/nax/project.commit=$(git rev-parse --short HEAD)" ./cmd/monax`

func NotesAndInstall added in v0.0.25

func NotesAndInstall() string

NotesAndInstall assembles the notes and installation instructions for the templates

func RpmInstall added in v0.0.25

func RpmInstall() string

RpmInstall provides the rpm install instructions

func SnapInstall added in v0.0.25

func SnapInstall() string

SnapInstall provides the snap install instructions

func SourceInstall added in v0.0.25

func SourceInstall() string

SourceInstall provides the install by source instructions

func WindowsInstall added in v0.0.25

func WindowsInstall() string

WindowsInstall provides the scoops install instructions

Types

This section is empty.

Directories

Path Synopsis
cmd
changelog command
install command
notes command
version command

Jump to