Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var History relic.ImmutableHistory = relic.NewHistory("Nax", "https://github.com/monax/nax").
MustDeclareReleases(
"0.0.19", "Final test for setup?",
"0.0.18", "Github actions are all set up and we now have a new tool overview in cmd.",
"0.0.17", "At some point this is gonna be settled. Adding scoop, refining snaps.",
"0.0.16", `Houston
pronounced HOW-stun
we are good for liftoff`,
"0.0.15", "Fixups",
"0.0.14", `The tool has been renamed from MONAX to nax.
The license has also been changed from Parity v6.0 to Apache v2.0
this is due to the neccesity for software that is "touched" by
Parity to be made publicly available. That is a good thing which
marmots generally support, but in the case of this API wrapper
it implicates packages of contracts and templates touched
by this software and my [@compleatang] interpretation of this
is that there is an application of the license to these contracts
which would violate the intention of the tool. As such I have
chosen, for now to move to Apache v2.0.
`,
"0.0.13", "Last go!",
"0.0.12", "Renamed tool to just MONAX; finalized release pathways",
"0.0.11", "Okay, I think I found the problem",
"0.0.10", "Once more into the breach",
"0.0.9", "Final answer?",
"0.0.8", "More releaser tweaks",
"0.0.7", "I think we've got it now",
"0.0.6", "Finish up infrastructure tests -- hopefully",
"0.0.5", "Testing release process with goreleaser",
"0.0.4",
`Next release of Monax Sync which has most of the target infrastructure done.
Currently we have the base infrastructure for:
- cli
- cli help text
- versioning
- notes + changelog
- logging
- basic project structure
Next steps:
- build tests based on mocks from monax-go
- build tests based on object structures extracted from monax's demo content
- make the tests go red
Targets:
1. deploy and sync archetypes
2. deploy and sync agreements (with demo content filled in)
3. manage users and organizations`,
"0.0.3", "Even more boilerplate",
"0.0.2", "More boilerplate",
"0.0.1",
`First release of Monax synx extracted from various initial projects, it can:
- Set up it's template
`)
History is the releases described by version string and changes, newest release first. The current release is taken to be the first release in the slice, and its version determines the single authoritative version for the next release.
To cut a new release add a release to the front of this slice then run the release tagging script: ./scripts/tag_release.sh
Functions ¶
func FullVersion ¶
func FullVersion() string
FullVersion Can be used to set the commit hash version of the binary at build time with: `go build -ldflags "-X github.com/monax/nax/project.commit=$(git rev-parse --short HEAD)" ./cmd/monax`
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.